@@ -835,7 +835,7 @@ def GetFunctionResourceSpec():
 
 
 def AddFunctionResourceArg(parser, verb, required=True):
-  """Adds a Cloud function resource argument.
+  """Adds a Cloud Function resource argument.
 
   NOTE: May be used only if it's the only resource arg in the command.
 
@@ -847,7 +847,7 @@ def AddFunctionResourceArg(parser, verb, required=True):
   concept_parsers.ConceptParser.ForResource(
       'NAME',
       GetFunctionResourceSpec(),
-      'The Cloud function name {}.'.format(verb),
+      'The Cloud Function name {}.'.format(verb),
       required=required,
   ).AddToParser(parser)
 
@@ -1044,6 +1044,11 @@ def AddDockerRepositoryFlags(parser):
         must be an Artifact Registry Docker repository present in the `same`
         project and location as the Cloud Function.
 
+        **Preview:** for 2nd gen functions, a Docker Artifact registry
+        repository in a different project and/or location may be used.
+        Additional requirements apply, see
+        https://cloud.google.com/functions/docs/building#image_registry
+
         The repository name should match one of these patterns:
 
         * `projects/${PROJECT}/locations/${LOCATION}/repositories/${REPOSITORY}`,
