@@ -21,6 +21,13 @@ from __future__ import unicode_literals
 import argparse
 
 from googlecloudsdk.core import exceptions
+from googlecloudsdk.generated_clients.apis.networkconnectivity.v1beta.networkconnectivity_v1beta_messages import GoogleCloudNetworkconnectivityV1betaGatewayAdvertisedRoute
+
+
+# Constants
+PROJECTS_RESOURCE_PATH = "projects/"
+LOCATION_FILTER_FMT = "location:projects/{0}/locations/{1}"
+ROUTE_TYPE_FILTER = "-type:DYNAMIC_ROUTE"
 
 
 class NetworkConnectivityError(exceptions.Error):
@@ -81,6 +88,32 @@ def AppendLocationsGlobalToParent(unused_ref, unused_args, request):
   return request
 
 
+def DeriveProjectFromResource(resource):
+  """Returns the project from a resource string."""
+  if PROJECTS_RESOURCE_PATH not in resource:
+    raise InvalidInputError(
+        "Resource must contain a project path, but received: {0}".format(
+            resource
+        )
+    )
+  project = resource[
+      resource.index(PROJECTS_RESOURCE_PATH) + len(PROJECTS_RESOURCE_PATH) :
+  ]
+  project = project.split("/")[0]
+  return project
+
+
+def AppendEffectiveLocationFilter(unused_ref, args, request):
+  """Append filter to limit listing dynamic routes at an effective location."""
+
+  if args.IsSpecified("effective_location"):
+    location = args.effective_location
+    project = DeriveProjectFromResource(request.parent)
+    location_filter = LOCATION_FILTER_FMT.format(project, location)
+    request.filter = "{0} OR {1}".format(location_filter, ROUTE_TYPE_FILTER)
+  return request
+
+
 def SetGlobalLocation():
   """Set default location to global."""
   return "global"
@@ -147,16 +180,80 @@ class StoreGlobalAction(argparse._StoreConstAction):
   # pylint: disable=redefined-builtin
   """Return "global" if the --global argument is used."""
 
-  def __init__(self,
-               option_strings,
-               dest,
-               default="",
-               required=False,
-               help=None):
+  def __init__(
+      self, option_strings, dest, default="", required=False, help=None
+  ):
     super(StoreGlobalAction, self).__init__(
         option_strings=option_strings,
         dest=dest,
         const="global",
         default=default,
         required=required,
-        help=help)
+        help=help,
+    )
+
+
+def SetGatewayAdvertisedRouteRecipient(unused_ref, args, request):
+  """Set the route's `recipient` field based on boolean flags.
+
+  Args:
+    args: The command arguments.
+    request: The request to set the `recipient` field on.
+  Returns:
+    The request with the `recipient` field set.
+  """
+  if args.advertise_to_hub:
+    request.googleCloudNetworkconnectivityV1betaGatewayAdvertisedRoute.recipient = (
+        GoogleCloudNetworkconnectivityV1betaGatewayAdvertisedRoute.RecipientValueValuesEnum.ADVERTISE_TO_HUB
+    )
+  return request
+
+
+def CheckRegionSpecifiedIfSpokeSpecified(unused_ref, unused_args, request):
+  """If a spoke name is specified, then its region must also be specified.
+
+  This is because CCFE doesn't support a wildcard ("-") in this case but returns
+  a confusing error message. So we give the user a friendlier error.
+
+  Args:
+    request: The request object. We will inspect the parent field.
+
+  Returns:
+    The unmodified request object.
+  Raises:
+    InvalidInputError: If the region is unspecified when a spoke is.
+  """
+  region_wildcard = "/locations/-/" in request.parent
+  spoke_wildcard = request.parent.endswith("/spokes/-")
+  if region_wildcard and not spoke_wildcard:
+    raise InvalidInputError(
+        "A region must be specified if a spoke name is specified"
+    )
+  return request
+
+
+def CheckForRouteTableAndHubWildcardMismatch(unused_ref, unused_args, request):
+  """Check that hub and route table are both specified or both unspecified.
+
+  This is because CCFE doesn't support wildcards ("-") in this case but returns
+  a confusing error message. So we give he user a friendlier error.
+
+  Args:
+   request: The request object.
+  Returns:
+    The unmodified request object.
+  Raises:
+    InvalidInputError: If the user needs to specify a hub name or route table
+    name.
+  """
+  hub_wildcard = "/hubs/-/" in request.parent
+  route_table_wildcard = request.parent.endswith("/routeTables/-")
+  if hub_wildcard and not route_table_wildcard:
+    raise InvalidInputError(
+        "A hub must be specified if a route table is specified"
+    )
+  if route_table_wildcard and not hub_wildcard:
+    raise InvalidInputError(
+        "A route table must be specified if a hub is specified"
+    )
+  return request
