@@ -21,9 +21,11 @@ from __future__ import print_function
 from __future__ import unicode_literals
 
 import re
+import textwrap
 
 from apitools.base.py import encoding
 from googlecloudsdk.api_lib.scc import securitycenter_client as sc_client
+from googlecloudsdk.calliope import actions
 from googlecloudsdk.calliope import arg_parsers
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.scc import errors
@@ -31,7 +33,6 @@ from googlecloudsdk.command_lib.util.args import resource_args
 from googlecloudsdk.command_lib.util.concepts import concept_parsers
 from googlecloudsdk.core import properties
 
-# TODO: b/312478509 - Add Deprecation warning for compare-duration.
 COMPARE_DURATION_FLAG = base.Argument(
     '--compare-duration',
     help="""
@@ -63,6 +64,15 @@ COMPARE_DURATION_FLAG = base.Argument(
       findings present at read_time. If this field is set then 'state_change'
       must be a specified field in 'group_by'. See $ gcloud topic datetimes
       for information on supported duration formats.""",
+    action=actions.DeprecationAction(
+        '--compare-duration',
+        warn=textwrap.dedent("""\
+            The --compare-duration option is deprecated.
+            For more information, [see the deprecation notice]
+            (https://cloud.google.com/security-command-center/docs/release-notes#April_15_2024)
+            on the SCC release notes page."""),
+        removed=False,
+    ),
 )
 
 EVENT_TIME_FLAG_NOT_REQUIRED = base.Argument(
