@@ -41,7 +41,7 @@ DEFAULT_RELEASE_TRACK = base.ReleaseTrack.GA
 STORAGE_TYPE_MAPPING = {
     'HDD': 'PD_HDD',
     'SSD': 'PD_SSD',
-    'HDB': 'HYPERDISK_BALANCED',
+    'HYPERDISK_BALANCED': 'HYPERDISK_BALANCED',
 }
 
 
