@@ -31,14 +31,15 @@ from googlecloudsdk.core import log
 from googlecloudsdk.core import properties
 from googlecloudsdk.core.util import files
 from googlecloudsdk.core.util import hashing
+from googlecloudsdk.core.util import platforms
 from googlecloudsdk.core.util import scaled_integer
 
 
 # The maximum length of a file name can vary wildly between operating
 # systems, so always ensure that tracker files are less than 100 characters.
-_MAX_TRACKER_FILE_NAME_LENGTH = 100
+_MAX_FILE_NAME_LENGTH = 100
 _TRAILING_FILE_NAME_CHARACTERS_FOR_DISPLAY = 16
-_RE_DELIMITER_PATTERN = r'[/\\]'
+RE_DELIMITER_PATTERN = r'[/\\]'
 
 
 class TrackerFileType(enum.Enum):
@@ -93,7 +94,26 @@ def _create_tracker_directory_if_needed():
   return tracker_directory
 
 
-def _get_hashed_file_name(file_name):
+def _windows_sanitize_file_name(file_name):
+  """Converts colons and characters that make Windows upset."""
+  if (
+      platforms.OperatingSystem.Current() == platforms.OperatingSystem.WINDOWS
+      and properties.VALUES.storage.convert_incompatible_windows_path_characters.GetBool()
+  ):
+    return platforms.MakePathWindowsCompatible(file_name)
+  return file_name
+
+
+def raise_exceeds_max_length_error(file_name):
+  if len(file_name) > _MAX_FILE_NAME_LENGTH:
+    raise errors.Error(
+        'File name is over max character limit of {}: {}'.format(
+            _MAX_FILE_NAME_LENGTH, file_name
+        )
+    )
+
+
+def get_hashed_file_name(file_name):
   """Applies a hash function (SHA1) to shorten the passed file name.
 
   The spec for the hashed file name is as follows:
@@ -101,7 +121,7 @@ def _get_hashed_file_name(file_name):
   'hash' is a SHA1 hash on the original file name, and 'trailing' is
   the last chars of the original file name. Max file name lengths
   vary by operating system, so the goal of this function is to ensure
-  the hashed version takes fewer than _MAX_TRACKER_FILE_NAME_LENGTH characters.
+  the hashed version takes fewer than _MAX_FILE_NAME_LENGTH  characters.
 
   Args:
     file_name (str): File name to be hashed. May be unicode or bytes.
@@ -110,13 +130,20 @@ def _get_hashed_file_name(file_name):
     String of shorter, hashed file_name.
   """
   name_hash_object = hashlib.sha1(file_name.encode('utf-8'))
-  return 'TRACKER_{}.{}'.format(
-      name_hash_object.hexdigest(),
-      file_name[-1 * _TRAILING_FILE_NAME_CHARACTERS_FOR_DISPLAY:])
+  return _windows_sanitize_file_name(
+      '{}.{}'.format(
+          name_hash_object.hexdigest(),
+          file_name[-1 * _TRAILING_FILE_NAME_CHARACTERS_FOR_DISPLAY :],
+      )
+  )
 
 
-def _get_hashed_path(tracker_file_name, tracker_file_type,
-                     resumable_tracker_directory, component_number):
+def _get_hashed_tracker_file_path(
+    tracker_file_name,
+    tracker_file_type,
+    resumable_tracker_directory,
+    component_number,
+):
   """Hashes and returns a tracker file path.
 
   Args:
@@ -133,19 +160,22 @@ def _get_hashed_path(tracker_file_name, tracker_file_type,
   Raises:
     Error: Hashed file path is too long.
   """
-  hashed_tracker_file_name = _get_hashed_file_name(tracker_file_name)
-  tracker_file_name_with_type = '{}_{}'.format(tracker_file_type.value.lower(),
-                                               hashed_tracker_file_name)
-  if component_number is not None:
-    tracker_file_name_with_type += '_{}'.format(component_number)
+  hashed_tracker_file_name = get_hashed_file_name(tracker_file_name)
+  tracker_file_name_with_type = '{}_TRACKER_{}'.format(
+      tracker_file_type.value.lower(), hashed_tracker_file_name
+  )
+  if component_number is None:
+    final_tracker_file_name = tracker_file_name_with_type
+  else:
+    final_tracker_file_name = tracker_file_name_with_type + '_{}'.format(
+        component_number
+    )
 
-  if len(tracker_file_name_with_type) > _MAX_TRACKER_FILE_NAME_LENGTH:
-    raise errors.Error(
-        'Tracker file name hash is over max character limit of {}: {}'.format(
-            _MAX_TRACKER_FILE_NAME_LENGTH, tracker_file_name_with_type))
+  raise_exceeds_max_length_error(final_tracker_file_name)
 
-  tracker_file_path = (
-      resumable_tracker_directory + os.sep + tracker_file_name_with_type)
+  tracker_file_path = os.path.join(
+      resumable_tracker_directory, final_tracker_file_name
+  )
   return tracker_file_path
 
 
@@ -206,11 +236,28 @@ def get_tracker_file_path(destination_url,
         destination_url.bucket_name, destination_url.object_name,
         destination_url.scheme.value)
 
-  result_tracker_file_name = re.sub(_RE_DELIMITER_PATTERN, '_',
-                                    raw_result_tracker_file_name)
+  result_tracker_file_name = get_delimiterless_file_path(
+      raw_result_tracker_file_name
+  )
   resumable_tracker_directory = _create_tracker_directory_if_needed()
-  return _get_hashed_path(result_tracker_file_name, tracker_file_type,
-                          resumable_tracker_directory, component_number)
+  return _get_hashed_tracker_file_path(
+      result_tracker_file_name,
+      tracker_file_type,
+      resumable_tracker_directory,
+      component_number,
+  )
+
+
+def get_delimiterless_file_path(file_path):
+  """Returns a string representation of the given path without any delimiters.
+
+  Args:
+    file_path (str): Path from which delimiters should be removed.
+
+  Returns:
+    A copy of file_path without any delimiters.
+  """
+  return re.sub(RE_DELIMITER_PATTERN, '_', file_path)
 
 
 def _get_sliced_download_tracker_file_paths(destination_url):
@@ -299,7 +346,7 @@ def hash_gcs_rewrite_parameters_for_tracker_file(source_object_resource,
     MD5 hex digest (string) of the input parameters.
 
   Raises:
-    ValueError if argument is missing required property.
+    Error if argument is missing required property.
   """
   mandatory_parameters = (source_object_resource.storage_url.bucket_name,
                           source_object_resource.storage_url.object_name,
@@ -307,10 +354,10 @@ def hash_gcs_rewrite_parameters_for_tracker_file(source_object_resource,
                           destination_object_resource.storage_url.bucket_name,
                           destination_object_resource.storage_url.object_name)
   if not all(mandatory_parameters):
-    raise ValueError('Missing required parameter values.')
+    raise errors.Error('Missing required parameter values.')
 
   source_encryption = (
-      source_object_resource.decryption_key_hash or
+      source_object_resource.decryption_key_hash_sha256 or
       source_object_resource.kms_key)
   destination_encryption = None
   if (request_config and request_config.resource_args and
@@ -426,11 +473,12 @@ def write_tracker_file_with_component_data(tracker_file_path,
   }
   if slice_start_byte is not None:
     if total_components is not None:
-      raise ValueError(
+      raise errors.Error(
           'Cannot have a tracker file with slice_start_byte and'
           ' total_components. slice_start_byte signals a component within a'
           ' larger operation. total_components signals the parent tracker for'
-          ' a multi-component operation.')
+          ' a multi-component operation.'
+      )
     component_data['slice_start_byte'] = slice_start_byte
   if total_components is not None:
     component_data['total_components'] = total_components
@@ -520,10 +568,11 @@ def read_or_create_download_tracker_file(source_object_resource,
         'Source object resource is missing etag.')
   if total_components and (slice_start_byte is not None or
                            component_number is not None):
-    raise ValueError(
+    raise errors.Error(
         'total_components indicates this is the parent tracker file for a'
         ' multi-component operation. slice_start_byte and component_number'
-        ' cannot be present since this is not for an individual component.')
+        ' cannot be present since this is not for an individual component.'
+    )
 
   if component_number is not None:
     download_name_for_logger = '{} component {}'.format(
