@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2017 Google Inc. All Rights Reserved.
+# Copyright 2017 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -30,6 +30,10 @@ class JavaError(exceptions.Error):
   pass
 
 
+class JavaVersionError(JavaError):
+  pass
+
+
 def RequireJavaInstalled(for_text, min_version=7):
   """Require that a certain version of Java is installed.
 
@@ -59,7 +63,7 @@ def RequireJavaInstalled(for_text, min_version=7):
                     ' The {for_text} requires a Java {v}+ JRE installed and on '
                     'your system PATH'.format(for_text=for_text, v=min_version))
 
-  java_exec_version_error = JavaError(
+  java_exec_version_error = JavaVersionError(
       'The java executable on your PATH is not a Java {v}+ JRE.'
       ' The {for_text} requires a Java {v}+ JRE installed and on '
       'your system PATH'.format(v=min_version, for_text=for_text))
