@@ -80,6 +80,48 @@ def AddDisallowUnauthenticatedCorsPreflightRequestsToggleFlag(parser):
   )
 
 
+def AddDisableLocalhostReplacementFlag(parser):
+  """Adds a --disable-localhost-replacement flag to the given parser."""
+  help_text = """\
+    By default, the workstations service replaces references to localhost,
+    127.0.0.1, and 0.0.0.0 with the workstation's hostname in http responses
+    from the workstation so that applications under development run properly
+    on the workstation. This may intefere with some applications, and so
+    this option allows that behavior to be disabled.
+  """
+  parser.add_argument(
+      '--disable-localhost-replacement',
+      action='store_true',
+      help=help_text,
+  )
+
+
+def AddDisableLocalhostReplacementToggleFlag(parser):
+  """Adds a --enable-localhost-replacement flag to the given parser."""
+  help_text = """\
+    By default, the workstations service replaces references to localhost,
+    127.0.0.1, and 0.0.0.0 with the workstation's hostname in http responses
+    from the workstation so that applications under development run properly
+    on the workstation. This may intefere with some applications, and so
+    this option allows that behavior to be disabled.
+  """
+
+  group = parser.add_mutually_exclusive_group()
+  group.add_argument(
+      '--disable-localhost-replacement',
+      action='store_true',
+      help=help_text,
+  )
+
+  help_text = """\
+  If set, requires that all requests to the workstation are authenticated."""
+  group.add_argument(
+      '--enable-localhost-replacement',
+      action='store_true',
+      help=help_text,
+  )
+
+
 def AddAllowedPortsFlag(parser):
   """Adds a --allowed-ports flag to the given parser."""
   help_text = """\
@@ -350,7 +392,7 @@ def AddNetworkTags(parser):
 def AddPoolSize(parser, use_default=True):
   """Adds a --pool-size flag to the given parser."""
   help_text = """\
-  Number of instances to pool for faster Workstation starup."""
+  Number of instances to pool for faster Workstation startup."""
   parser.add_argument(
       '--pool-size',
       default=0 if use_default else None,
@@ -474,6 +516,21 @@ def AddEnableAuditAgent(parser, use_default=True):
   )
 
 
+def AddGrantWorkstationAdminRoleOnCreate(parser, use_default=True):
+  """Adds a --grant-workstation-admin-role-on-create flag to the given parser."""
+  help_text = """\
+  Default value is false.
+  If set, creator of a workstation will get `roles/workstations.policyAdmin`
+  role along with `roles/workstations.user` role on the workstation created by
+  them."""
+  parser.add_argument(
+      '--grant-workstation-admin-role-on-create',
+      action='store_true',
+      default=False if use_default else None,
+      help=help_text,
+  )
+
+
 def AddEnableConfidentialCompute(parser, use_default=True):
   """Adds an --enable-confidential-compute flag to the given parser."""
   help_text = """\
@@ -524,11 +581,12 @@ def AddPdDiskType(parser):
   )
 
 
-def AddPdDiskSize(parser):
-  """Adds a --pd-disk-size flag to the given parser."""
+def AddPdDiskSizeOrSnapshot(parser):
+  """Adds a --pd-disk-size and --pd-source-snapshot flag to the given parser."""
   help_text = """\
   Size of the persistent directory in GB."""
-  parser.add_argument(
+  group = parser.add_mutually_exclusive_group()
+  group.add_argument(
       '--pd-disk-size',
       choices=[10, 50, 100, 200, 500, 1000],
       default=200,
@@ -536,6 +594,14 @@ def AddPdDiskSize(parser):
       help=help_text,
   )
 
+  help_text = """\
+  Name of the snapshot to use as the source for the home disk."""
+  group.add_argument(
+      '--pd-source-snapshot',
+      default='',
+      help=help_text,
+  )
+
 
 def AddPdReclaimPolicy(parser):
   """Adds a --pd-reclaim-policy flag to the given parser."""
@@ -555,6 +621,17 @@ def AddPdReclaimPolicy(parser):
   )
 
 
+def AddPdSourceSnapshot(parser):
+  """Adds a --pd-source-snapshot flag to the given parser."""
+  help_text = """\
+  Name of the snapshot to use as the source for the home disk."""
+  parser.add_argument(
+      '--pd-source-snapshot',
+      default='',
+      help=help_text,
+  )
+
+
 def AddEphemeralDirectory(parser):
   spec = {
       'mount-path': str,
@@ -714,7 +791,7 @@ def AddCommandField(parser):
 
 
 def AddSshArgsAndUserField(parser):
-  """Adds a --user flag to the given parser."""
+  """Additional flags and positional args to be passed to *ssh(1)*."""
   help_text = """\
   The username with which to SSH.
   """
@@ -724,6 +801,17 @@ def AddSshArgsAndUserField(parser):
   Flags and positionals passed to the underlying ssh implementation."""
   parser.add_argument('ssh_args', nargs=argparse.REMAINDER, help=help_text)
 
+  help_text = """\
+  Additional flags to be passed to *ssh(1)*. It is recommended that flags
+  be passed using an assignment operator and quotes. Example:
+
+    $ {command} --ssh-flag="-vvv" --ssh-flag="-L 80:localhost:80"
+  """
+  parser.add_argument(
+      '--ssh-flag',
+      action='append',
+      help=help_text)
+
 
 def AddEncryptionKeyFields(parser):
   """Adds the --kms-key and --kms-key-service-account flags to the given parser."""
@@ -911,3 +999,21 @@ def AddVmTags(parser):
       type=arg_parsers.ArgDict(key_type=str, value_type=str),
       help=help_text,
   )
+
+
+def AddMaxUsableWorkstationsCount(parser):
+  """Adds a --max-usable-workstations-count flag to the given parser."""
+  help_text = """\
+  Maximum number of workstations under this configuration a user can have
+  `workstations.workstation.use` permission on.
+
+  If not specified, defaults to `0`, which indicates a user can have unlimited
+  number of workstations under this configuration."""
+
+  parser.add_argument(
+      '--max-usable-workstations-count',
+      metavar='MAX_USABLE_WORKSTATIONS_COUNT',
+      type=int,
+      default=0,
+      help=help_text,
+  )
