@@ -645,6 +645,20 @@ class ExecuteSqlRequest(proto.Message):
             If the field is set to ``true`` but the request does not set
             ``partition_token``, the API returns an ``INVALID_ARGUMENT``
             error.
+        last_statement (bool):
+            Optional. If set to true, this statement
+            marks the end of the transaction. The
+            transaction should be committed or aborted after
+            this statement executes, and attempts to execute
+            any other requests against this transaction
+            (including reads and queries) will be rejected.
+
+            For DML statements, setting this option may
+            cause some error reporting to be deferred until
+            commit time (e.g. validation of unique
+            constraints). Given this, successful execution
+            of a DML statement should not be assumed until a
+            subsequent Commit call completes successfully.
     """
     class QueryMode(proto.Enum):
         r"""Mode in which the statement must be processed.
@@ -806,6 +820,10 @@ class ExecuteSqlRequest(proto.Message):
         proto.BOOL,
         number=16,
     )
+    last_statement: bool = proto.Field(
+        proto.BOOL,
+        number=17,
+    )
 
 
 class ExecuteBatchDmlRequest(proto.Message):
@@ -847,6 +865,20 @@ class ExecuteBatchDmlRequest(proto.Message):
             yield the same response as the first execution.
         request_options (googlecloudsdk.generated_clients.gapic_clients.spanner_v1.types.RequestOptions):
             Common options for this request.
+        last_statements (bool):
+            Optional. If set to true, this request marks
+            the end of the transaction. The transaction
+            should be committed or aborted after these
+            statements execute, and attempts to execute any
+            other requests against this transaction
+            (including reads and queries) will be rejected.
+
+            Setting this option may cause some error
+            reporting to be deferred until commit time (e.g.
+            validation of unique constraints). Given this,
+            successful execution of statements should not be
+            assumed until a subsequent Commit call completes
+            successfully.
     """
 
     class Statement(proto.Message):
@@ -925,6 +957,10 @@ class ExecuteBatchDmlRequest(proto.Message):
         number=5,
         message='RequestOptions',
     )
+    last_statements: bool = proto.Field(
+        proto.BOOL,
+        number=6,
+    )
 
 
 class ExecuteBatchDmlResponse(proto.Message):
