@@ -74,10 +74,11 @@ class Create(base.CreateCommand):
         parser, alloydb_messages, cls.ReleaseTrack(), update=False
     )
     flags.AddContinuousBackupConfigFlags(parser, cls.ReleaseTrack())
-    flags.AddDatabaseVersion(parser, alloydb_messages, cls.ReleaseTrack())
+    flags.AddDatabaseVersion(parser, alloydb_messages)
     flags.AddEnablePrivateServiceConnect(parser)
     flags.AddMaintenanceWindow(parser, alloydb_messages)
     flags.AddSubscriptionType(parser, alloydb_messages)
+    flags.AddTags(parser)
 
   def ConstructCreateRequestFromArgs(self, alloydb_messages, location_ref,
                                      args):
