@@ -22,14 +22,14 @@ from __future__ import unicode_literals
 from googlecloudsdk.api_lib.compute import base_classes
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.compute import scp_utils
+from googlecloudsdk.core import log
 
-DEPRECATION_WARNING = (
-    '`gcloud compute copy-files` is deprecated.  Please use `gcloud compute '
-    'scp` instead.  Note that `gcloud compute scp` does not have recursive '
-    'copy on by default.  To turn on recursion, use the `--recurse` flag.')
+ENCOURAGE_SCP_INFO = (
+    'Consider using the `gcloud compute scp` command instead, which '
+    'includes support for internal IP connections and Identity-Aware '
+    'Proxy tunneling.')
 
 
-@base.Deprecate(is_removed=False, warning=DEPRECATION_WARNING)
 class CopyFiles(base.Command):
   """Copy files to and from Google Compute Engine virtual machines via scp."""
 
@@ -44,6 +44,8 @@ class CopyFiles(base.Command):
 
   def Run(self, args):
     """See scp_utils.BaseScpCommand.Run."""
+    log.warning(ENCOURAGE_SCP_INFO)
+
     holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
 
     scp_helper = scp_utils.BaseScpHelper()
@@ -61,18 +63,7 @@ CopyFiles.detailed_help = {
 
         To denote a remote file, prefix the file name with the virtual machine
         instance name (e.g., _example-instance_:~/_FILE_). To denote a local
-        file, do not add a prefix to the file name (e.g., ~/_FILE_). For
-        example, to copy a remote directory to your local host, run:
-
-          $ {command} example-instance:~/REMOTE-DIR ~/LOCAL-DIR --zone us-central1-a
-
-        In the above example, `~/REMOTE-DIR` from `example-instance` is copied
-        into the ~/_LOCAL-DIR_ directory.
-
-        Conversely, files from your local computer can be copied to a virtual
-        machine:
-
-          $ {command} ~/LOCAL-FILE-1 ~/LOCAL-FILE-2 example-instance:~/REMOTE-DIR --zone us-central1-a
+        file, do not add a prefix to the file name (e.g., ~/_FILE_).
 
         If a file contains a colon (``:''), you must specify it by either using
         an absolute path or a path that begins with
@@ -84,5 +75,17 @@ CopyFiles.detailed_help = {
         When the destination is local, all sources must be the same virtual
         machine instance. When the destination is remote, all sources must be
         local.
+        """,
+    'EXAMPLES':
+        """\
+          To copy a remote directory '~/REMOTE-DIR' on the instance of
+          'example-instance' to '~/LOCAL-DIR' on the local host, run:
+
+            $ {command} example-instance:~/REMOTE-DIR ~/LOCAL-DIR --zone=us-central1-a
+
+          To copy files from your local host to a virtual machine, run:
+
+            $ {command} ~/LOCAL-FILE-1 ~/LOCAL-FILE-2 example-instance:~/REMOTE-DIR --zone=us-central1-a
+
         """
 }
