@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2014 Google Inc. All Rights Reserved.
+# Copyright 2014 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,10 +21,20 @@ from __future__ import unicode_literals
 from googlecloudsdk.calliope import base
 
 
+@base.UniverseCompatible
 class MachineTypes(base.Group):
-  """Read Google Compute Engine virtual machine types."""
+  """Read Compute Engine virtual machine types."""
 
 
+MachineTypes.category = base.INFO_CATEGORY
+
 MachineTypes.detailed_help = {
-    'brief': 'Read Google Compute Engine virtual machine types',
+    'DESCRIPTION': """
+        Read Compute Engine virtual machine types.
+
+        For more information about machine types, see the
+        [machine types documentation](https://cloud.google.com/compute/docs/machine-types).
+
+        See also: [Machine types API](https://cloud.google.com/compute/docs/reference/rest/v1/machineTypes).
+    """,
 }
