@@ -1,4 +1,5 @@
-# Copyright 2015 Google Inc. All Rights Reserved.
+# -*- coding: utf-8 -*- #
+# Copyright 2015 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,11 +15,17 @@
 
 """Command to list named configuration."""
 
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import unicode_literals
+
 from googlecloudsdk.calliope import base
 from googlecloudsdk.core import properties
 from googlecloudsdk.core.configurations import named_configs
 from googlecloudsdk.core.configurations import properties_file
 
+import six
+
 
 class List(base.ListCommand):
   """Lists existing named configurations."""
@@ -41,10 +48,41 @@ class List(base.ListCommand):
   def Args(parser):
     base.PAGE_SIZE_FLAG.RemoveFromParser(parser)
     base.URI_FLAG.RemoveFromParser(parser)
+    configs = named_configs.ConfigurationStore.AllConfigs()
+    table_format = """table(
+        name,
+        is_active,
+        properties.core.account,
+        properties.core.project,
+        properties.compute.zone:label=COMPUTE_DEFAULT_ZONE,
+        properties.compute.region:label=COMPUTE_DEFAULT_REGION)
+    """
+    for _, config in sorted(six.iteritems(configs)):
+      props = properties.VALUES.AllValues(
+          list_unset=True,
+          include_hidden=True,
+          properties_file=properties_file.PropertiesFile([config.file_path]),
+      )
+      config_universe = props['core'].get('universe_domain')
+      if (
+          config_universe
+          and config_universe != properties.VALUES.core.universe_domain.default
+      ):
+        table_format = """table(
+          name,
+          is_active,
+          properties.core.account,
+          properties.core.project,
+          properties.core.universe_domain,
+          properties.compute.zone:label=COMPUTE_DEFAULT_ZONE,
+          properties.compute.region:label=COMPUTE_DEFAULT_REGION)
+      """
+        break
+    parser.display_info.AddFormat(table_format)
 
   def Run(self, args):
     configs = named_configs.ConfigurationStore.AllConfigs()
-    for _, config in sorted(configs.iteritems()):
+    for _, config in sorted(six.iteritems(configs)):
       props = properties.VALUES.AllValues(
           list_unset=True,
           properties_file=properties_file.PropertiesFile([config.file_path]),
@@ -54,12 +92,3 @@ class List(base.ListCommand):
           'is_active': config.is_active,
           'properties': props,
       }
-
-  def DeprecatedFormat(self, args):
-    return ('table('
-            'name,'
-            'is_active,'
-            'properties.core.account,'
-            'properties.core.project,'
-            'properties.compute.zone:label=DEFAULT_ZONE,'
-            'properties.compute.region:label=DEFAULT_REGION)')
