@@ -22,10 +22,9 @@ from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.projects import util
 
 
-@base.Hidden
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.GA)
 class Attached(base.Group):
-  """Deploy and manage clusters of machines on Attached for running containers."""
+  """Manage Attached clusters for running containers."""
 
   category = base.COMPUTE_CATEGORY
 
