@@ -18,6 +18,7 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
 
+from googlecloudsdk.api_lib.netapp import util as netapp_api_util
 from googlecloudsdk.api_lib.netapp.volumes.replications import client as replications_client
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.netapp import flags
@@ -47,13 +48,22 @@ class Create(base.CreateCommand):
 
   @staticmethod
   def Args(parser):
+    return Create._ReplicationArgs(parser, Create._RELEASE_TRACK)
+
+  @staticmethod
+  def _ReplicationArgs(parser, release_track):
     """Add args for creating a Replication."""
     concept_parsers.ConceptParser(
         [flags.GetReplicationPresentationSpec('The Replication to create.')]
     ).AddToParser(parser)
+    messages = netapp_api_util.GetMessagesModule(
+        release_track=release_track
+    )
     replications_flags.AddReplicationVolumeArg(parser)
     replications_flags.AddReplicationReplicationScheduleArg(parser)
-    replications_flags.AddReplicationDestinationVolumeParametersArg(parser)
+    replications_flags.AddReplicationDestinationVolumeParametersArg(
+        parser, messages
+    )
     replications_flags.AddReplicationClusterLocationArg(parser)
     flags.AddResourceAsyncFlag(parser)
     flags.AddResourceDescriptionArg(parser, 'Replication')
@@ -102,3 +112,6 @@ class CreateBeta(Create):
 
   _RELEASE_TRACK = base.ReleaseTrack.BETA
 
+  @staticmethod
+  def Args(parser):
+    return CreateBeta._ReplicationArgs(parser, CreateBeta._RELEASE_TRACK)
