@@ -41,7 +41,7 @@ from googlecloudsdk.core.console import progress_tracker
 EXAMPLE_JOB_IMAGE = 'us-docker.pkg.dev/cloudrun/container/job:latest'
 
 
-def ContainerArgGroup():
+def ContainerArgGroup(release_track=base.ReleaseTrack.GA):
   """Returns an argument group with all per-container deploy args."""
 
   help_text = """
@@ -55,6 +55,8 @@ Container Flags
   group.AddArgument(flags.MutexEnvVarsFlags())
   group.AddArgument(flags.MemoryFlag())
   group.AddArgument(flags.CpuFlag())
+  if release_track in [base.ReleaseTrack.ALPHA]:
+    group.AddArgument(flags.GpuFlag())
   group.AddArgument(flags.ArgsFlag())
   group.AddArgument(flags.SecretsFlags())
   group.AddArgument(flags.CommandFlag())
@@ -101,7 +103,7 @@ class Create(base.Command):
       flags.AddImageArg(parser, image=EXAMPLE_JOB_IMAGE)
       flags.AddArgsFlag(parser)
       flags.AddCommandFlag(parser)
-      flags.AddCpuFlag(parser, managed_only=True)
+      flags.AddCpuFlag(parser)
       flags.AddMemoryFlag(parser)
       flags.AddMutexEnvVarsFlagsForCreate(parser)
       flags.AddSetSecretsFlag(parser)
@@ -116,7 +118,7 @@ class Create(base.Command):
     flags.AddTasksFlag(parser)
     flags.AddMaxRetriesFlag(parser)
     flags.AddTaskTimeoutFlags(parser)
-    flags.AddServiceAccountFlag(parser, managed_only=True)
+    flags.AddServiceAccountFlag(parser)
     flags.AddSetCloudSQLFlag(parser)
     flags.AddVpcConnectorArg(parser)
     flags.AddVpcNetworkGroupFlagsForCreate(parser, resource_kind='job')
@@ -246,7 +248,9 @@ class BetaCreate(Create):
 
   @classmethod
   def Args(cls, parser):
-    cls.CommonArgs(parser)
+    cls.CommonArgs(parser, add_container_args=False)
+    container_args = ContainerArgGroup(release_track=base.ReleaseTrack.BETA)
+    container_parser.AddContainerFlags(parser, container_args)
 
 
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
@@ -257,5 +261,5 @@ class AlphaCreate(BetaCreate):
   def Args(cls, parser):
     cls.CommonArgs(parser, add_container_args=False)
     flags.AddRuntimeFlag(parser)
-    container_args = ContainerArgGroup()
+    container_args = ContainerArgGroup(release_track=base.ReleaseTrack.ALPHA)
     container_parser.AddContainerFlags(parser, container_args)
