@@ -139,7 +139,7 @@ def AddBaseArgs(parser):
   flags.AddEnableGooglePrivatePath(parser, show_negated_in_help=False)
   flags.AddThreadsPerCore(parser)
   flags.AddCascadableReplica(parser)
-  flags.AddEnableDataCache(parser, show_negated_in_help=False)
+  flags.AddEnableDataCache(parser)
   flags.AddRecreateReplicasOnPrimaryCrash(parser)
   psc_setup_group = parser.add_group()
   flags.AddEnablePrivateServiceConnect(psc_setup_group)
@@ -147,7 +147,8 @@ def AddBaseArgs(parser):
   flags.AddSslMode(parser)
   flags.AddEnableGoogleMLIntegration(parser)
   flags.AddEnableDataplexIntegration(parser)
-  flags.AddPscAutoConnections(parser, hidden=True)
+  flags.AddPscAutoConnections(parser)
+  flags.AddServerCaMode(parser)
   # (--
   # LINT.ThenChange(../backups/restore.py:instance_settings)
   # --)
@@ -160,8 +161,19 @@ def AddBetaArgs(parser):
   flags.AddAllocatedIpRangeName(parser)
   labels_util.AddCreateLabelsFlags(parser)
   flags.AddReplicationLagMaxSecondsForRecreate(parser)
-  flags.AddServerCaMode(parser)
   flags.AddRetainBackupsOnDelete(parser)
+  flags.AddStorageProvisionedIops(parser)
+  flags.AddStorageProvisionedThroughput(parser)
+  flags.AddEnableConnectionPooling(parser)
+  flags.AddConnectionPoolingPoolMode(parser)
+  flags.AddConnectionPoolingPoolSize(parser)
+  flags.AddConnectionPoolingMaxClientConnections(parser)
+  flags.AddConnectionPoolingClientIdleTimeout(parser)
+  flags.AddConnectionPoolingServerIdleTimeout(parser)
+  flags.AddConnectionPoolingQueryWaitTimeout(parser)
+  flags.AddCustomSubjectAlternativeNames(parser, hidden=True)
+  flags.AddServerCaPool(parser)
+  flags.AddTags(parser)
 
 
 def AddAlphaArgs(unused_parser):
@@ -324,6 +336,15 @@ def RunBaseCreateCommand(args, release_track):
         '`--psc-auto-connections` requires `--enable-private-service-connect`'
     )
 
+  # TODO(b/372040396): Add the check for server_ca_mode when it is supported.
+  if args.IsKnownAndSpecified(
+      'custom_subject_alternative_names'
+  ) and not args.IsKnownAndSpecified('server_ca_mode'):
+    raise sql_exceptions.ArgumentError(
+        '`--custom-subject-alternative-names` requires customer managed'
+        ' server CA'
+    )
+
   if args.database_flags is not None and any([
       'sync_binlog' in args.database_flags,
       'innodb_flush_log_at_trx_commit' in args.database_flags,
@@ -341,7 +362,7 @@ def RunBaseCreateCommand(args, release_track):
     can_infer_tier = (
         args.tier
         and command_util.DoesEnterprisePlusReplicaInferTierForDatabaseType(
-            sql_messages, args.database_version
+            args.database_version
         )
     )
     if not (args.IsSpecified('tier') or can_infer_tier):
