@@ -77,6 +77,7 @@ class Update(base.UpdateCommand):
     workstations_flags.AddContainerEnvField(parser)
     workstations_flags.AddContainerWorkingDirField(parser)
     workstations_flags.AddContainerRunAsUserField(parser)
+    workstations_flags.AddPdSourceSnapshot(parser)
     workstations_flags.AddLabelsField(parser)
     workstations_flags.AddAcceleratorFields(parser)
     workstations_flags.AddVmTags(parser)
@@ -87,6 +88,7 @@ class Update(base.UpdateCommand):
           parser
       )
       workstations_flags.AddBoostConfigs(parser)
+      workstations_flags.AddDisableLocalhostReplacementToggleFlag(parser)
 
   def Collection(self):
     return (
